import React from "react"
import ReactHtmlParser from 'react-html-parser'

import { graphql, Link } from "gatsby"
import clip from "text-clipper"

import Layout from "../parts/layout"
import Seo from "../parts/seo"

const DepsPage = ({ data }) => {
  return (
    <Layout>
      <Seo title="Deps" />
      <div className="row">
        <h1 className="page-title">DEPS</h1>
        <h2>{data.strapiDepsPage.subtitle}</h2>
        <div className="page-introduction">{ ReactHtmlParser(data.strapiDepsPage.introduction) }</div>

        <h3 style={{ marginBottom: "2rem" }}>articles</h3>
        <div className="items">
          { data.allStrapiArticle.nodes.map(node => {
            const excerpt = node.excerpt ? node.excerpt : clip(node.body, 150, { html: true })

            const date = new Date(node.date)

            return (
              <div key={node.id} className="item box">
                <div className="text">
                  <div className="meta">{ date.toLocaleDateString("en-GB", { day: 'numeric', month: 'short', year: 'numeric' }) } / <em>{ node.author }</em></div>
                  <h2><Link to={`/articles/${node.slug}`}>{ node.title }</Link></h2>
                  { ReactHtmlParser(excerpt) }
                </div>
                <div className="buttons">
                  <Link className="button" to={`/articles/${node.slug}`}>Read more...</Link>
                </div>
              </div>
            )
          }) }
        </div>
      </div>
    </Layout>
  )
}

export default DepsPage

export const pageQuery = graphql`
  query ArticlesQuery {
    strapiDepsPage {
      subtitle
      introduction
    }
    allStrapiArticle(sort: {order: DESC, fields: published_at}) {
      nodes {
        id
        slug
        date
        author
        title
        excerpt
        body
      }
    }
  }
`